package com.chinaitop.depot.storage.controller;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.storage.model.StorageGrainDisposal;
import com.chinaitop.depot.storage.model.StorageGrainDisposalView;
import com.chinaitop.depot.storage.service.StorageGrainDisposalService;
import com.chinaitop.depot.unissoft.model.ResponseEntity;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.google.common.collect.Maps;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * 粮情处置controller
 * @author aihua
 * @date 2022-04-17 14:41
 */
@RestController
@RequestMapping("/grainDisposal")
@Api(value = "StorageGrainDisposalController", description = "粮情处置-主页")
@RequiredArgsConstructor
@Slf4j
public class StorageGrainDisposalController {
    private final StorageGrainDisposalService storageGrainDisposalService;

    @RequestMapping(value = "/getList",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="查询粮情处置", notes = "查询粮情处置信息列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构ID", paramType = "query"),
            @ApiImplicitParam(name = "storeHouseName", value = "仓房名称", paramType = "query"),
            @ApiImplicitParam(name = "wareHouseName", value = "货位名称", paramType = "query")
    })
    public ResponseEntity<PageInfo<StorageGrainDisposalView>> listPage(Integer pageNum, Integer pageSize, Integer orgId, String storeHouseName, String wareHouseName){
        if (orgId == null) {
            return ResponseEntity.failed("组织机构ID不能为空！");
        }
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        Map<String, Object> queryMap = Maps.newHashMap();
        if (StringUtils.isNotBlank(storeHouseName)) {
            queryMap.put("storeHouseName", storeHouseName);
        }
        if (StringUtils.isNotBlank(wareHouseName)) {
            queryMap.put("wareHouseName", wareHouseName);
        }
        queryMap.put("orgId", orgId);
        List<StorageGrainDisposalView> list = storageGrainDisposalService.selectListPage(queryMap);
        PageInfo<StorageGrainDisposalView> pageInfo = new PageInfo<>(list);
        return ResponseEntity.ok(pageInfo);
    }

    @RequestMapping(value = "/saveData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "保存粮情处置", notes = "保存粮情处置")
    @ApiImplicitParam(name = "riskJson", value = "JSON数据对象", paramType = "form")
    public ResponseEntity saveData(String riskJson) {
        try {
            log.info("粮情处置saveDate：" + riskJson);
            if (StringUtils.isNotBlank(riskJson)) {
                StorageGrainDisposal storageGrainDisposal = JSONObject.parseObject(riskJson, StorageGrainDisposal.class);
                storageGrainDisposalService.saveData(storageGrainDisposal);
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed(e.getMessage());
        }
        return ResponseEntity.ok();
    }

    @RequestMapping(value = "/updateData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "更新粮情处置", notes = "更新粮情处置")
    @ApiImplicitParam(name = "riskJson", value = "JSON数据对象", paramType = "form")
    public ResponseEntity updateData(String riskJson) {
        try {
            log.info("粮情处置updateDate：" + riskJson);
            if (StringUtils.isNotBlank(riskJson)) {
                StorageGrainDisposal storageGrainDisposal = JSONObject.parseObject(riskJson, StorageGrainDisposal.class);
                if (storageGrainDisposal.getId() == null) {
                    return ResponseEntity.failed("更新数据ID不能为空！");
                }
                storageGrainDisposalService.updateDate(storageGrainDisposal);
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed(e.getMessage());
        }
        return ResponseEntity.ok();
    }

    @RequestMapping(value = "/deleteRisk", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="根据主键id移除数据信息", notes = "根据主键id移除数据信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数据ID", paramType = "form")
    })
    public ResponseEntity deleteRisk(Integer id) {
        try {
            if (id == null) {
                return ResponseEntity.failed("数据ID不能为空！");
            }
            storageGrainDisposalService.deleteById(id);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed(e.getMessage());
        }
        return ResponseEntity.ok();
    }

    @RequestMapping(value = "queryById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "根据id加载对应数据", notes = "根据id加载对应数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
    })
    public ResponseEntity<StorageGrainDisposal> queryById(Integer id) {
        try {
            if (id == null) {
                return ResponseEntity.failed("数据ID不能为空！");
            }
            return ResponseEntity.ok(storageGrainDisposalService.queryById(id));
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed(e.getMessage());
        }
    }
}
